---
title: House-Warming
id: house-warming
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 13
kind: article
---

## House-Warming

In October I went a-graping to the river meadows, and loaded myself
with clusters more precious for their beauty and fragrance than for
food. There too I admired, though I did not gather, the cranberries,
small waxen gems, pendants of the meadow grass, pearly and red, which
the farmer plucks with an ugly rake, leaving the smooth meadow in a
snarl, heedlessly measuring them by the bushel and the dollar only, and
sells the spoils of the meads to Boston and New York; destined to be
_jammed_, to satisfy the tastes of lovers of Nature there. So butchers
rake the tongues of bison out of the prairie grass, regardless of the
torn and drooping plant. The barberry’s brilliant fruit was likewise
food for my eyes merely; but I collected a small store of wild apples
for coddling, which the proprietor and travellers had overlooked. When
chestnuts were ripe I laid up half a bushel for winter. It was very
exciting at that season to roam the then boundless chestnut woods of
Lincoln,—they now sleep their long sleep under the railroad,—with a bag
on my shoulder, and a stick to open burrs with in my hand, for I did
not always wait for the frost, amid the rustling of leaves and the loud
reproofs of the red-squirrels and the jays, whose half-consumed nuts I
sometimes stole, for the burrs which they had selected were sure to
contain sound ones. Occasionally I climbed and shook the trees. They
grew also behind my house, and one large tree, which almost
overshadowed it, was, when in flower, a bouquet which scented the whole
neighborhood, but the squirrels and the jays got most of its fruit; the
last coming in flocks early in the morning and picking the nuts out of
the burrs before they fell. I relinquished these trees to them and
visited the more distant woods composed wholly of chestnut. These nuts,
as far as they went, were a good substitute for bread. Many other
substitutes might, perhaps, be found. Digging one day for fish-worms, I
discovered the ground-nut (_Apios tuberosa_) on its string, the potato
of the aborigines, a sort of fabulous fruit, which I had begun to doubt
if I had ever dug and eaten in childhood, as I had told, and had not
dreamed it. I had often since seen its crimpled red velvety blossom
supported by the stems of other plants without knowing it to be the
same. Cultivation has well nigh exterminated it. It has a sweetish
taste, much like that of a frostbitten potato, and I found it better
boiled than roasted. This tuber seemed like a faint promise of Nature
to rear her own children and feed them simply here at some future
period. In these days of fatted cattle and waving grain-fields this
humble root, which was once the _totem_ of an Indian tribe, is quite
forgotten, or known only by its flowering vine; but let wild Nature
reign here once more, and the tender and luxurious English grains will
probably disappear before a myriad of foes, and without the care of man
the crow may carry back even the last seed of corn to the great
cornfield of the Indian’s God in the south-west, whence he is said to
have brought it; but the now almost exterminated ground-nut will
perhaps revive and flourish in spite of frosts and wildness, prove
itself indigenous, and resume its ancient importance and dignity as the
diet of the hunter tribe. Some Indian Ceres or Minerva must have been
the inventor and bestower of it; and when the reign of poetry commences
here, its leaves and string of nuts may be represented on our works of
art.

Already, by the first of September, I had seen two or three small
maples turned scarlet across the pond, beneath where the white stems of
three aspens diverged, at the point of a promontory, next the water.
Ah, many a tale their color told! And gradually from week to week the
character of each tree came out, and it admired itself reflected in the
smooth mirror of the lake. Each morning the manager of this gallery
substituted some new picture, distinguished by more brilliant or
harmonious coloring, for the old upon the walls.

The wasps came by thousands to my lodge in October, as to winter
quarters, and settled on my windows within and on the walls over-head,
sometimes deterring visitors from entering. Each morning, when they
were numbed with cold, I swept some of them out, but I did not trouble
myself much to get rid of them; I even felt complimented by their
regarding my house as a desirable shelter. They never molested me
seriously, though they bedded with me; and they gradually disappeared,
into what crevices I do not know, avoiding winter and unspeakable cold.

Like the wasps, before I finally went into winter quarters in November,
I used to resort to the north-east side of Walden, which the sun,
reflected from the pitch-pine woods and the stony shore, made the
fire-side of the pond; it is so much pleasanter and wholesomer to be
warmed by the sun while you can be, than by an artificial fire. I thus
warmed myself by the still glowing embers which the summer, like a
departed hunter, had left.



When I came to build my chimney I studied masonry. My bricks being
second-hand ones required to be cleaned with a trowel, so that I
learned more than usual of the qualities of bricks and trowels. The
mortar on them was fifty years old, and was said to be still growing
harder; but this is one of those sayings which men love to repeat
whether they are true or not. Such sayings themselves grow harder and
adhere more firmly with age, and it would take many blows with a trowel
to clean an old wiseacre of them. Many of the villages of Mesopotamia
are built of second-hand bricks of a very good quality, obtained from
the ruins of Babylon, and the cement on them is older and probably
harder still. However that may be, I was struck by the peculiar
toughness of the steel which bore so many violent blows without being
worn out. As my bricks had been in a chimney before, though I did not
read the name of Nebuchadnezzar on them, I picked out as many
fire-place bricks as I could find, to save work and waste, and I filled
the spaces between the bricks about the fire-place with stones from the
pond shore, and also made my mortar with the white sand from the same
place. I lingered most about the fireplace, as the most vital part of
the house. Indeed, I worked so deliberately, that though I commenced at
the ground in the morning, a course of bricks raised a few inches above
the floor served for my pillow at night; yet I did not get a stiff neck
for it that I remember; my stiff neck is of older date. I took a poet
to board for a fortnight about those times, which caused me to be put
to it for room. He brought his own knife, though I had two, and we used
to scour them by thrusting them into the earth. He shared with me the
labors of cooking. I was pleased to see my work rising so square and
solid by degrees, and reflected, that, if it proceeded slowly, it was
calculated to endure a long time. The chimney is to some extent an
independent structure, standing on the ground and rising through the
house to the heavens; even after the house is burned it still stands
sometimes, and its importance and independence are apparent. This was
toward the end of summer. It was now November.



The north wind had already begun to cool the pond, though it took many
weeks of steady blowing to accomplish it, it is so deep. When I began
to have a fire at evening, before I plastered my house, the chimney
carried smoke particularly well, because of the numerous chinks between
the boards. Yet I passed some cheerful evenings in that cool and airy
apartment, surrounded by the rough brown boards full of knots, and
rafters with the bark on high overhead. My house never pleased my eye
so much after it was plastered, though I was obliged to confess that it
was more comfortable. Should not every apartment in which man dwells be
lofty enough to create some obscurity over-head, where flickering
shadows may play at evening about the rafters? These forms are more
agreeable to the fancy and imagination than fresco paintings or other
the most expensive furniture. I now first began to inhabit my house, I
may say, when I began to use it for warmth as well as shelter. I had
got a couple of old fire-dogs to keep the wood from the hearth, and it
did me good to see the soot form on the back of the chimney which I had
built, and I poked the fire with more right and more satisfaction than
usual. My dwelling was small, and I could hardly entertain an echo in
it; but it seemed larger for being a single apartment and remote from
neighbors. All the attractions of a house were concentrated in one
room; it was kitchen, chamber, parlor, and keeping-room; and whatever
satisfaction parent or child, master or servant, derive from living in
a house, I enjoyed it all. Cato says, the master of a family
(_patremfamilias_) must have in his rustic villa “cellam oleariam,
vinariam, dolia multa, uti lubeat caritatem expectare, et rei, et
virtuti, et gloriæ erit,” that is, “an oil and wine cellar, many casks,
so that it may be pleasant to expect hard times; it will be for his
advantage, and virtue, and glory.” I had in my cellar a firkin of
potatoes, about two quarts of peas with the weevil in them, and on my
shelf a little rice, a jug of molasses, and of rye and Indian meal a
peck each.

I sometimes dream of a larger and more populous house, standing in a
golden age, of enduring materials, and without ginger-bread work, which
shall still consist of only one room, a vast, rude, substantial,
primitive hall, without ceiling or plastering, with bare rafters and
purlins supporting a sort of lower heaven over one’s head,—useful to
keep off rain and snow; where the king and queen posts stand out to
receive your homage, when you have done reverence to the prostrate
Saturn of an older dynasty on stepping over the sill; a cavernous
house, wherein you must reach up a torch upon a pole to see the roof;
where some may live in the fire-place, some in the recess of a window,
and some on settles, some at one end of the hall, some at another, and
some aloft on rafters with the spiders, if they choose; a house which
you have got into when you have opened the outside door, and the
ceremony is over; where the weary traveller may wash, and eat, and
converse, and sleep, without further journey; such a shelter as you
would be glad to reach in a tempestuous night, containing all the
essentials of a house, and nothing for house-keeping; where you can see
all the treasures of the house at one view, and every thing hangs upon
its peg, that a man should use; at once kitchen, pantry, parlor,
chamber, store-house, and garret; where you can see so necessary a
thing as a barrel or a ladder, so convenient a thing as a cupboard, and
hear the pot boil, and pay your respects to the fire that cooks your
dinner and the oven that bakes your bread, and the necessary furniture
and utensils are the chief ornaments; where the washing is not put out,
nor the fire, nor the mistress, and perhaps you are sometimes requested
to move from off the trap-door, when the cook would descend into the
cellar, and so learn whether the ground is solid or hollow beneath you
without stamping. A house whose inside is as open and manifest as a
bird’s nest, and you cannot go in at the front door and out at the back
without seeing some of its inhabitants; where to be a guest is to be
presented with the freedom of the house, and not to be carefully
excluded from seven eighths of it, shut up in a particular cell, and
told to make yourself at home there,—in solitary confinement. Nowadays
the host does not admit you to _his_ hearth, but has got the mason to
build one for yourself somewhere in his alley, and hospitality is the
art of _keeping_ you at the greatest distance. There is as much secrecy
about the cooking as if he had a design to poison you. I am aware that
I have been on many a man’s premises, and might have been legally
ordered off, but I am not aware that I have been in many men’s houses.
I might visit in my old clothes a king and queen who lived simply in
such a house as I have described, if I were going their way; but
backing out of a modern palace will be all that I shall desire to
learn, if ever I am caught in one.

It would seem as if the very language of our parlors would lose all its
nerve and degenerate into _palaver_ wholly, our lives pass at such
remoteness from its symbols, and its metaphors and tropes are
necessarily so far fetched, through slides and dumb-waiters, as it
were; in other words, the parlor is so far from the kitchen and
workshop. The dinner even is only the parable of a dinner, commonly. As
if only the savage dwelt near enough to Nature and Truth to borrow a
trope from them. How can the scholar, who dwells away in the North West
Territory or the Isle of Man, tell what is parliamentary in the
kitchen?

However, only one or two of my guests were ever bold enough to stay and
eat a hasty-pudding with me; but when they saw that crisis approaching
they beat a hasty retreat rather, as if it would shake the house to its
foundations. Nevertheless, it stood through a great many
hasty-puddings.

I did not plaster till it was freezing weather. I brought over some
whiter and cleaner sand for this purpose from the opposite shore of the
pond in a boat, a sort of conveyance which would have tempted me to go
much farther if necessary. My house had in the mean while been shingled
down to the ground on every side. In lathing I was pleased to be able
to send home each nail with a single blow of the hammer, and it was my
ambition to transfer the plaster from the board to the wall neatly and
rapidly. I remembered the story of a conceited fellow, who, in fine
clothes, was wont to lounge about the village once, giving advice to
workmen. Venturing one day to substitute deeds for words, he turned up
his cuffs, seized a plasterer’s board, and having loaded his trowel
without mishap, with a complacent look toward the lathing overhead,
made a bold gesture thitherward; and straightway, to his complete
discomfiture, received the whole contents in his ruffled bosom. I
admired anew the economy and convenience of plastering, which so
effectually shuts out the cold and takes a handsome finish, and I
learned the various casualties to which the plasterer is liable. I was
surprised to see how thirsty the bricks were which drank up all the
moisture in my plaster before I had smoothed it, and how many pailfuls
of water it takes to christen a new hearth. I had the previous winter
made a small quantity of lime by burning the shells of the _Unio
fluviatilis_, which our river affords, for the sake of the experiment;
so that I knew where my materials came from. I might have got good
limestone within a mile or two and burned it myself, if I had cared to
do so.



The pond had in the mean while skimmed over in the shadiest and
shallowest coves, some days or even weeks before the general freezing.
The first ice is especially interesting and perfect, being hard, dark,
and transparent, and affords the best opportunity that ever offers for
examining the bottom where it is shallow; for you can lie at your
length on ice only an inch thick, like a skater insect on the surface
of the water, and study the bottom at your leisure, only two or three
inches distant, like a picture behind a glass, and the water is
necessarily always smooth then. There are many furrows in the sand
where some creature has travelled about and doubled on its tracks; and,
for wrecks, it is strewn with the cases of cadis worms made of minute
grains of white quartz. Perhaps these have creased it, for you find
some of their cases in the furrows, though they are deep and broad for
them to make. But the ice itself is the object of most interest, though
you must improve the earliest opportunity to study it. If you examine
it closely the morning after it freezes, you find that the greater part
of the bubbles, which at first appeared to be within it, are against
its under surface, and that more are continually rising from the
bottom; while the ice is as yet comparatively solid and dark, that is,
you see the water through it. These bubbles are from an eightieth to an
eighth of an inch in diameter, very clear and beautiful, and you see
your face reflected in them through the ice. There may be thirty or
forty of them to a square inch. There are also already within the ice
narrow oblong perpendicular bubbles about half an inch long, sharp
cones with the apex upward; or oftener, if the ice is quite fresh,
minute spherical bubbles one directly above another, like a string of
beads. But these within the ice are not so numerous nor obvious as
those beneath. I sometimes used to cast on stones to try the strength
of the ice, and those which broke through carried in air with them,
which formed very large and conspicuous white bubbles beneath. One day
when I came to the same place forty-eight hours afterward, I found that
those large bubbles were still perfect, though an inch more of ice had
formed, as I could see distinctly by the seam in the edge of a cake.
But as the last two days had been very warm, like an Indian summer, the
ice was not now transparent, showing the dark green color of the water,
and the bottom, but opaque and whitish or gray, and though twice as
thick was hardly stronger than before, for the air bubbles had greatly
expanded under this heat and run together, and lost their regularity;
they were no longer one directly over another, but often like silvery
coins poured from a bag, one overlapping another, or in thin flakes, as
if occupying slight cleavages. The beauty of the ice was gone, and it
was too late to study the bottom. Being curious to know what position
my great bubbles occupied with regard to the new ice, I broke out a
cake containing a middling sized one, and turned it bottom upward. The
new ice had formed around and under the bubble, so that it was included
between the two ices. It was wholly in the lower ice, but close against
the upper, and was flattish, or perhaps slightly lenticular, with a
rounded edge, a quarter of an inch deep by four inches in diameter; and
I was surprised to find that directly under the bubble the ice was
melted with great regularity in the form of a saucer reversed, to the
height of five eighths of an inch in the middle, leaving a thin
partition there between the water and the bubble, hardly an eighth of
an inch thick; and in many places the small bubbles in this partition
had burst out downward, and probably there was no ice at all under the
largest bubbles, which were a foot in diameter. I inferred that the
infinite number of minute bubbles which I had first seen against the
under surface of the ice were now frozen in likewise, and that each, in
its degree, had operated like a burning glass on the ice beneath to
melt and rot it. These are the little air-guns which contribute to make
the ice crack and whoop.



At length the winter set in in good earnest, just as I had finished
plastering, and the wind began to howl around the house as if it had
not had permission to do so till then. Night after night the geese came
lumbering in in the dark with a clangor and a whistling of wings, even
after the ground was covered with snow, some to alight in Walden, and
some flying low over the woods toward Fair Haven, bound for Mexico.
Several times, when returning from the village at ten or eleven o’clock
at night, I heard the tread of a flock of geese, or else ducks, on the
dry leaves in the woods by a pond-hole behind my dwelling, where they
had come up to feed, and the faint honk or quack of their leader as
they hurried off. In 1845 Walden froze entirely over for the first time
on the night of the 22d of December, Flint’s and other shallower ponds
and the river having been frozen ten days or more; in ’46, the 16th; in
’49, about the 31st; and in ’50, about the 27th of December; in ’52,
the 5th of January; in ’53, the 31st of December. The snow had already
covered the ground since the 25th of November, and surrounded me
suddenly with the scenery of winter. I withdrew yet farther into my
shell, and endeavored to keep a bright fire both within my house and
within my breast. My employment out of doors now was to collect the
dead wood in the forest, bringing it in my hands or on my shoulders, or
sometimes trailing a dead pine tree under each arm to my shed. An old
forest fence which had seen its best days was a great haul for me. I
sacrificed it to Vulcan, for it was past serving the god Terminus. How
much more interesting an event is that man’s supper who has just been
forth in the snow to hunt, nay, you might say, steal, the fuel to cook
it with! His bread and meat are sweet. There are enough fagots and
waste wood of all kinds in the forests of most of our towns to support
many fires, but which at present warm none, and, some think, hinder the
growth of the young wood. There was also the drift-wood of the pond. In
the course of the summer I had discovered a raft of pitch-pine logs
with the bark on, pinned together by the Irish when the railroad was
built. This I hauled up partly on the shore. After soaking two years
and then lying high six months it was perfectly sound, though
waterlogged past drying. I amused myself one winter day with sliding
this piecemeal across the pond, nearly half a mile, skating behind with
one end of a log fifteen feet long on my shoulder, and the other on the
ice; or I tied several logs together with a birch withe, and then, with
a longer birch or alder which had a hook at the end, dragged them
across. Though completely waterlogged and almost as heavy as lead, they
not only burned long, but made a very hot fire; nay, I thought that
they burned better for the soaking, as if the pitch, being confined by
the water, burned longer, as in a lamp.

Gilpin, in his account of the forest borderers of England, says that
“the encroachments of trespassers, and the houses and fences thus
raised on the borders of the forest,” were “considered as great
nuisances by the old forest law, and were severely punished under the
name of _purprestures_, as tending _ad terrorem ferarum—ad nocumentum
forestæ_, &c.,” to the frightening of the game and the detriment of the
forest. But I was interested in the preservation of the venison and the
vert more than the hunters or woodchoppers, and as much as though I had
been the Lord Warden himself; and if any part was burned, though I
burned it myself by accident, I grieved with a grief that lasted longer
and was more inconsolable than that of the proprietors; nay, I grieved
when it was cut down by the proprietors themselves. I would that our
farmers when they cut down a forest felt some of that awe which the old
Romans did when they came to thin, or let in the light to, a
consecrated grove (_lucum conlucare_), that is, would believe that it
is sacred to some god. The Roman made an expiatory offering, and
prayed, Whatever god or goddess thou art to whom this grove is sacred,
be propitious to me, my family, and children, &c.

It is remarkable what a value is still put upon wood even in this age
and in this new country, a value more permanent and universal than that
of gold. After all our discoveries and inventions no man will go by a
pile of wood. It is as precious to us as it was to our Saxon and Norman
ancestors. If they made their bows of it, we make our gun-stocks of it.
Michaux, more than thirty years ago, says that the price of wood for
fuel in New York and Philadelphia “nearly equals, and sometimes
exceeds, that of the best wood in Paris, though this immense capital
annually requires more than three hundred thousand cords, and is
surrounded to the distance of three hundred miles by cultivated
plains.” In this town the price of wood rises almost steadily, and the
only question is, how much higher it is to be this year than it was the
last. Mechanics and tradesmen who come in person to the forest on no
other errand, are sure to attend the wood auction, and even pay a high
price for the privilege of gleaning after the woodchopper. It is now
many years that men have resorted to the forest for fuel and the
materials of the arts; the New Englander and the New Hollander, the
Parisian and the Celt, the farmer and Robinhood, Goody Blake and Harry
Gill, in most parts of the world the prince and the peasant, the
scholar and the savage, equally require still a few sticks from the
forest to warm them and cook their food. Neither could I do without
them.

Every man looks at his wood-pile with a kind of affection. I love to
have mine before my window, and the more chips the better to remind me
of my pleasing work. I had an old axe which nobody claimed, with which
by spells in winter days, on the sunny side of the house, I played
about the stumps which I had got out of my bean-field. As my driver
prophesied when I was ploughing, they warmed me twice, once while I was
splitting them, and again when they were on the fire, so that no fuel
could give out more heat. As for the axe, I was advised to get the
village blacksmith to “jump” it; but I jumped him, and, putting a
hickory helve from the woods into it, made it do. If it was dull, it
was at least hung true.

A few pieces of fat pine were a great treasure. It is interesting to
remember how much of this food for fire is still concealed in the
bowels of the earth. In previous years I had often gone “prospecting”
over some bare hill-side, where a pitch-pine wood had formerly stood,
and got out the fat pine roots. They are almost indestructible. Stumps
thirty or forty years old, at least, will still be sound at the core,
though the sapwood has all become vegetable mould, as appears by the
scales of the thick bark forming a ring level with the earth four or
five inches distant from the heart. With axe and shovel you explore
this mine, and follow the marrowy store, yellow as beef tallow, or as
if you had struck on a vein of gold, deep into the earth. But commonly
I kindled my fire with the dry leaves of the forest, which I had stored
up in my shed before the snow came. Green hickory finely split makes
the woodchopper’s kindlings, when he has a camp in the woods. Once in a
while I got a little of this. When the villagers were lighting their
fires beyond the horizon, I too gave notice to the various wild
inhabitants of Walden vale, by a smoky streamer from my chimney, that I
was awake.—

     Light-winged Smoke, Icarian bird,
     Melting thy pinions in thy upward flight,
     Lark without song, and messenger of dawn,
     Circling above the hamlets as thy nest;
     Or else, departing dream, and shadowy form
     Of midnight vision, gathering up thy skirts;
     By night star-veiling, and by day
     Darkening the light and blotting out the sun;
     Go thou my incense upward from this hearth,
     And ask the gods to pardon this clear flame.

Hard green wood just cut, though I used but little of that, answered my
purpose better than any other. I sometimes left a good fire when I went
to take a walk in a winter afternoon; and when I returned, three or
four hours afterward, it would be still alive and glowing. My house was
not empty though I was gone. It was as if I had left a cheerful
housekeeper behind. It was I and Fire that lived there; and commonly my
housekeeper proved trustworthy. One day, however, as I was splitting
wood, I thought that I would just look in at the window and see if the
house was not on fire; it was the only time I remember to have been
particularly anxious on this score; so I looked and saw that a spark
had caught my bed, and I went in and extinguished it when it had burned
a place as big as my hand. But my house occupied so sunny and sheltered
a position, and its roof was so low, that I could afford to let the
fire go out in the middle of almost any winter day.

The moles nested in my cellar, nibbling every third potato, and making
a snug bed even there of some hair left after plastering and of brown
paper; for even the wildest animals love comfort and warmth as well as
man, and they survive the winter only because they are so careful to
secure them. Some of my friends spoke as if I was coming to the woods
on purpose to freeze myself. The animal merely makes a bed, which he
warms with his body, in a sheltered place; but man, having discovered
fire, boxes up some air in a spacious apartment, and warms that,
instead of robbing himself, makes that his bed, in which he can move
about divested of more cumbrous clothing, maintain a kind of summer in
the midst of winter, and by means of windows even admit the light, and
with a lamp lengthen out the day. Thus he goes a step or two beyond
instinct, and saves a little time for the fine arts. Though, when I had
been exposed to the rudest blasts a long time, my whole body began to
grow torpid, when I reached the genial atmosphere of my house I soon
recovered my faculties and prolonged my life. But the most luxuriously
housed has little to boast of in this respect, nor need we trouble
ourselves to speculate how the human race may be at last destroyed. It
would be easy to cut their threads any time with a little sharper blast
from the north. We go on dating from Cold Fridays and Great Snows; but
a little colder Friday, or greater snow, would put a period to man’s
existence on the globe.

The next winter I used a small cooking-stove for economy, since I did
not own the forest; but it did not keep fire so well as the open
fire-place. Cooking was then, for the most part, no longer a poetic,
but merely a chemic process. It will soon be forgotten, in these days
of stoves, that we used to roast potatoes in the ashes, after the
Indian fashion. The stove not only took up room and scented the house,
but it concealed the fire, and I felt as if I had lost a companion. You
can always see a face in the fire. The laborer, looking into it at
evening, purifies his thoughts of the dross and earthiness which they
have accumulated during the day. But I could no longer sit and look
into the fire, and the pertinent words of a poet recurred to me with
new force.—

     “Never, bright flame, may be denied to me
     Thy dear, life imaging, close sympathy.
     What but my hopes shot upward e’er so bright?
     What but my fortunes sunk so low in night?

     Why art thou banished from our hearth and hall,
     Thou who art welcomed and beloved by all?
     Was thy existence then too fanciful
     For our life’s common light, who are so dull?
     Did thy bright gleam mysterious converse hold
     With our congenial souls? secrets too bold?
     Well, we are safe and strong, for now we sit
     Beside a hearth where no dim shadows flit,
     Where nothing cheers nor saddens, but a fire
     Warms feet and hands—nor does to more aspire;
     By whose compact utilitarian heap
     The present may sit down and go to sleep,
     Nor fear the ghosts who from the dim past walked,
     And with us by the unequal light of the old wood fire talked.”



